<p align="center">
  <img src="https://github.com/IglooCloud/igloo.py/blob/master/IglooLogo.png" alt="Igloo logo" width="128"/>
</p>

<h1 align="center">igloo_python</h1>

igloo_python is the official Igloo library for Python.

## Getting started

TBD

## Publishing the package

```bash
python3 setup.py sdist bdist_wheel
twine upload dist/*
```

## License

See the [license](https://raw.githubusercontent.com/IglooCloud/igloo_python/master/LICENSE) file for license rights and limitations.
